@@ -1325,13 +1325,14 @@ class SimulatedTemperingSimulation(MDSimulation):
 
     """
     def __init__(self, numTemperatures=7, minTemperature=300 * unit.kelvin, maxTemperature=450 * unit.kelvin,
-                 reportInterval=1000, reportFile='weights.dat', **kwargs):
+                 tempChangeInterval = 50, reportInterval=1000, weights = None, reportFile='weights.dat', **kwargs):
         super().__init__(**kwargs)
         self.minTemperature = minTemperature
         self.maxTemperature = maxTemperature
         self.numTemperatures = numTemperatures
         self.reportInterval = reportInterval
-
+        self.tempChangeInterval = tempChangeInterval
+        self.weights = weights
         self.reportFile = reportFile
 
         self._build_custom_forces()
@@ -1343,6 +1344,8 @@ class SimulatedTemperingSimulation(MDSimulation):
                                                   minTemperature=self.minTemperature,
                                                   maxTemperature=self.maxTemperature,
                                                   reportInterval=self.reportInterval,
+                                                  tempChangeInterval = self.tempChangeInterval,
+                                                  weights=self.weights,
                                                   reportFile=os.path.join(self.cwd,self.reportFile))
 
     def run(self, time):
@@ -1367,8 +1370,6 @@ class SimulatedTemperingSimulation(MDSimulation):
 
 
 
-
-
 if __name__ == '__main__':
     import _pickle as pickle
 
